@@ -2,7 +2,7 @@
 //! `linemd` is a simple and opinionated markdown parsing library.
 
 extern crate alloc;
-#[cfg(feature = "html")]
+#[cfg(any(feature = "html", feature = "svg"))]
 use alloc::format;
 use alloc::{
     boxed::Box,
@@ -24,7 +24,7 @@ pub use parser::{Parser, Token};
 
 #[cfg(feature = "svg")]
 #[doc(inline)]
-pub use svg::render_as_svg;
+pub use svg::{render_as_svg, Config as SvgConfig, ViewportDimensions as SvgViewportDimensions};
 
 #[cfg(feature = "html")]
 #[doc(inline)]
