@@ -1,4 +1,4 @@
-use linemd::{parse, render_as_html, render_as_svg};
+use linemd::{parse, render_as_html, render_as_svg, SvgConfig};
 use std::io::{prelude::*, stdin};
 
 const HELP_TEXT: &str = include_str!("help.txt");
@@ -30,8 +30,13 @@ fn main() {
             }
         };
 
-        let render = if svg { render_as_svg } else { render_as_html };
-        println!("{}", render(parse(md)));
+        let tokens = parse(md);
+        let out = if svg {
+            render_as_svg(tokens, SvgConfig::default())
+        } else {
+            render_as_html(tokens)
+        };
+        println!("{}", out);
     } else {
         println!("{}", HELP_TEXT);
     }
